@@ -1,7 +1,7 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: html.tcl,v 1.23 1999/01/16 16:21:55 jfontain Exp $}
+set rcsId {$Id: html.tcl,v 1.24 1999/01/17 20:16:16 jfontain Exp $}
 
 # use bold and smaller sizes than the HTML library default ones for headers
 array set HMtag_map {
@@ -22,8 +22,7 @@ set HMtag_map(hmstart) {
 
 # make headers and preformatted text stand out better by adding new lines around them.
 array set HMinsert_map {
-    h1 "\n\n" /h1 "\n\n" h2 "\n\n" /h2 "\n\n" h3 "\n\n" /h3 "\n\n" h4 "\n\n" /h4 "\n\n" h5 "\n\n" /h5 "\n\n" h6 "\n\n" /h6 "\n\n"
-    pre "\n\n" /pre "\n\n"
+    h1 \n\n /h1 \n\n h2 \n\n /h2 \n\n h3 \n\n /h3 \n\n h4 \n\n /h4 \n\n h5 \n\n /h5 \n\n h6 \n\n /h6 \n\n pre \n\n /pre \n\n
 }
 
 unset HMevents(Enter)                                                     ;# prevent links highlighting, try to behave like Netscape
@@ -41,8 +40,8 @@ proc HMlink_callback {widget reference} {
 proc HMset_image {widget label source} {                                                          ;# supply image handling procedure
     if {\
         [catch {image create photo -file $source} image]&&\
-        [catch {image create photo -file [file join /usr/doc/moodss-$::applicationVersion $source]} image]\
-    } return                                                  ;# local directory and rpm documentation directory searched and failed
+        [catch {image create photo -file [file join $::widgetHTMLDirectory($widget) $source]} image]\
+    } return                                                             ;# local directory and widget directory searched and failed
     bind $label <Destroy> "image delete $image"                      ;# setup binding so that image is deleted as label is destroyed
     HMgot_image $label $image                                                               ;# got the image for the specified label
 }
@@ -96,6 +95,11 @@ proc generalHelpWindow {} {
     HMset_state $contentsText -stop 1                                                        ;# stop rendering previous page if busy
 
     set htmlHelpDataText $composite::($widget,scrolled,path)                                      ;# now setup and display help text
+
+    # use rpm documentation directory for images repository
+    set ::widgetHTMLDirectory($htmlHelpDataText) /usr/doc/moodss-$::applicationVersion
+    bind $htmlHelpDataText <Destroy> "unset ::widgetHTMLDirectory($htmlHelpDataText)"
+
     $htmlHelpDataText configure -cursor watch                                             ;# show that we are busy for user feedback
     update idletasks
 
@@ -128,6 +132,11 @@ proc moduleHelpWindow {name} {
     bind .topHelp.bound <Destroy> "delete $widget"
 
     set htmlHelpDataText $composite::($widget,scrolled,path)                                          ;# setup and display help text
+
+    # use module directory for images repository
+    set ::widgetHTMLDirectory($htmlHelpDataText) $::packageDirectory($name)
+    bind $htmlHelpDataText <Destroy> "unset ::widgetHTMLDirectory($htmlHelpDataText)"
+
     $htmlHelpDataText configure -cursor watch                                             ;# show that we are busy for user feedback
     update idletasks
 
