@@ -1,7 +1,7 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: modules.tcl,v 1.3 1999/01/11 20:50:37 jfontain Exp $}
+set rcsId {$Id: modules.tcl,v 1.4 1999/01/16 16:21:26 jfontain Exp $}
 
 class modules {
 
@@ -66,4 +66,22 @@ class modules {
         initializeNext $arguments                                                                                ;# process the rest
     }
 
+    proc helpHTMLData {module} {   ;# return HTML formatted module help no matter whether provided plain or preformatted from module
+        if {[catch {set ${module}::data(helpText)} text]} {
+            set text {no help available}
+        }
+        set header "<H6>module $module</H6>\n<I>version [package provide $module]"
+        if {[string length $modules::($module,arguments)]>0} {
+            append header ", invoked with arguments: $modules::($module,arguments)"
+        }
+        append header </I><BR><BR>\n
+        if {[string first <BODY> $text]<0} {                                                                         ;# regular help
+            regsub -all \n $text <BR> text                                                               ;# keep original formatting
+            return ${header}$text
+        } else {                                                                                              ;# HTML formatted help
+            regsub <BODY> $text <BODY>\n$header text                                                                ;# insert header
+            return $text
+        }
+    }
+
 }
