@@ -1,7 +1,7 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: record.tcl,v 1.14 1998/12/26 10:43:44 jfontain Exp $}
+set rcsId {$Id: record.tcl,v 1.17 1999/01/11 20:51:11 jfontain Exp $}
 
 
 class record {
@@ -37,9 +37,9 @@ class record {
         puts $file "width [winfo width .] height [winfo height .]"
         puts $file "pollTime $::pollTime"
         puts $file "modules \{"
-        foreach module $::modules(all) {
+        foreach module $modules::(all) {
             puts $file "    $module \{"
-            puts $file "        arguments {}"                                                              ;### when implemented ###
+            puts $file "        arguments \{$modules::($module,arguments)\}"
             puts $file "        tables \{"
             foreach table $dataTable::(list) {
                 # filter other module tables
@@ -93,6 +93,15 @@ class record {
         return [array names data]
     }
 
+    proc modulesWithArguments {this} {           ;# return list of format: module [-option [value] -option ...] module [-option ...]
+        set list {}
+        foreach module [modules $this] {
+            moduleData $this $module data
+            eval lappend list $module $data(arguments)
+        }
+        return $list
+    }
+
     proc pollTime {this} {
         variable ${this}data
 
@@ -123,13 +132,19 @@ class record {
         return $list
     }
 
+    proc moduleData {this module dataName} {
+        variable ${this}data
+        upvar $dataName data
+
+        array set all [set ${this}data(modules)]
+        array set data $all($module)
+    }
+
     proc tableData {this module creationIndex dataName} {              ;# index is module data table creation index, starting with 0
         variable ${this}data
         upvar $dataName data
 
-        array set data [set ${this}data(modules)]
-        array set moduleData $data($module)
-        unset data
+        moduleData $this $module moduleData
         array set tablesData $moduleData(tables)
         unset moduleData
         set data(level) {}              ;# for backward compatibility when level was not stored in save file (versions 5.1 and down)
