@@ -1,7 +1,7 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: utility.tcl,v 1.7 1999/01/10 20:06:25 jfontain Exp $}
+set rcsId {$Id: utility.tcl,v 1.8 1999/01/17 20:13:37 jfontain Exp $}
 
 proc minimum {a b} {return [expr {$a<$b?$a:$b}]}
 proc maximum {a b} {return [expr {$a>$b?$a:$b}]}
@@ -34,3 +34,18 @@ proc commaSeparatedString {words} {
     append string [lindex $words $index]
     return $string
 }
+
+proc startGatheringPackageDirectories {} {
+    catch {rename source _source}
+    proc source {file} {
+        foreach name [package names] {
+            set package($name) {}
+        }
+        uplevel _source [list $file]
+        foreach name [package names] {                                                        ;# see what new packages are available
+            if {![info exists package($name)]} {
+                set ::packageDirectory($name) [file dirname $file]
+            }
+        }
+    }
+}
