@@ -1,7 +1,7 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: viewer.tcl,v 1.20 1998/12/26 10:43:44 jfontain Exp $}
+set rcsId {$Id: viewer.tcl,v 1.21 1999/01/04 14:34:28 jfontain Exp $}
 
 class viewer {                                                                             ;# handle viewers related functionalities
     # viewers do not derive from a common interface class but rather support a common set a options through the composite class
@@ -70,8 +70,11 @@ class viewer {
     }
 
     proc label {array row column} {   ;# derive a label from cell using the tabular data index columns. array name must be qualified
+        if {[catch {set ${array}(indexColumns)} columns]} {                                                      ;# no index columns
+            set columns 0                                                                 ;# use first column as single index column
+        }
         set label {}
-        foreach index [set ${array}(indexColumns)] {                                                  ;# use index columns for label
+        foreach index $columns {                                                                      ;# use index columns for label
             if {[catch {set ${array}($row,$index)} value]} {
                 append label {? }               ;# cell may no longer exist if originating from a save file, give user some feedback
             } else {
